pub const fn is_error_kind(kind: u16) -> boolExpand description
Whether the kind will match parsing error occurred in the source code.
This is used to match parsing error in the source code.
for example, we can use kind: ERROR in YAML to find invalid syntax in source.
the name is_error implies the matcher itself is error.
But here the matcher itself is valid and it is what it matches is error.