Root

Struct Root 

pub struct Root<D: Doc> { /* private fields */ }
Root of an AST tree that owns the source code and parsed tree structure.

Root acts as the entry point for all AST operations. It manages the document (source code + parsed tree) and provides methods to get the root node and perform tree-wide operations like replacements.

Generic Parameters

  • D: Doc - The document type that holds source code and language information

Example

let mut ast = Language::Tsx.ast_grep("let x = 42;");
let root_node = ast.root();

// Perform tree-wide replacements
ast.replace("let $VAR = $VALUE", "const $VAR = $VALUE");
println!("{}", ast.generate());

Implementations

Source

impl<D: Doc> Root<D>

pub const fn doc(doc: D) -> Self

pub fn lang(&self) -> &D::Lang

pub fn root(&self) -> Node<'_, D>

The root node represents the entire source

pub fn edit( &mut self, edit: &Edit<<D as Doc>::Source>, ) -> Result<&mut Self, String>

pub fn replace<M: Matcher, R: Replacer<D>>( &mut self, pattern: M, replacer: R, ) -> Result<bool, String>

pub fn adopt<'r>(&'r self, inner: D::Node<'r>) -> Node<'r, D>

Adopt the tree_sitter as the descendant of the root and return the wrapped sg Node. It assumes inner is under the root and will panic at dev build if wrong node is used.

Source

impl<L: LanguageExt> Root<StrDoc<L>>

pub fn new<S: AsRef<str>>(src: S, lang: L) -> Self

pub fn source(&self) -> &str

pub fn generate(self) -> String

Source

impl<L: LanguageExt> Root<StrDoc<L>>

pub fn str(src: &str, lang: L) -> Self

pub fn try_new(src: &str, lang: L) -> Result<Self, String>

pub fn get_text(&self) -> &str

pub fn get_injections<F: Fn(&str) -> Option<L>>(&self, get_lang: F) -> Vec<Self>