Visitor

Struct Visitor 

pub struct Visitor<M, A = PreOrder> { /* private fields */ }
Configurable tree visitor that combines traversal algorithms with pattern matching.

Visitor allows you to traverse an AST while filtering nodes based on patterns. It supports different traversal algorithms and provides fine-grained control over matching behavior through reentrancy and node type filtering.

Type Parameters

  • M: Matcher - The pattern matcher to filter nodes
  • A - The traversal algorithm (defaults to PreOrder)

Example

let ast = Tsx.ast_grep("let x = foo(); let y = bar();");
let root = ast.root();

// Find all identifiers, visiting only named nodes
let identifiers: Vec<_> = Visitor::new("$ID")
    .named_only(true)
    .reentrant(false)
    .visit(root)
    .collect();

Implementations

Source

impl<M> Visitor<M>

pub const fn new(matcher: M) -> Self

Source

impl<M, A> Visitor<M, A>

pub fn algorithm<Algo>(self) -> Visitor<M, Algo>

pub fn reentrant(self, reentrant: bool) -> Self

pub fn named_only(self, named_only: bool) -> Self

Source

impl<M, A> Visitor<M, A>
where A: Algorithm,

pub fn visit<L: LanguageExt>( self, node: Node<'_, StrDoc<L>>, ) -> Visit<'_, StrDoc<L>, A::Traversal<'_, L>, M>
where M: Matcher,